@@ -88,6 +88,9 @@ public class AltosConfigData {
 
 	public int		report_feet;
 
+	/* HAS_GPS_MOSAIC */
+	public int		gps_receiver;
+
 	/* Storage info replies */
 	public int	storage_size;
 	public int	storage_erase_unit;
@@ -220,9 +223,13 @@ public class AltosConfigData {
 		case AltosLib.AO_LOG_FORMAT_TELEMEGA_5:
 		case AltosLib.AO_LOG_FORMAT_TELEMEGA_6:
 		case AltosLib.AO_LOG_FORMAT_EASYMEGA_2:
+		case AltosLib.AO_LOG_FORMAT_EASYMEGA_3:
 		case AltosLib.AO_LOG_FORMAT_EASYMOTOR:
 			/* ADXL375 */
 			return -value;
+		case AltosLib.AO_LOG_FORMAT_EASYTIMER_2:
+			/* BMI088 */
+			return -value;
 		default:
 			if (product.startsWith("EasyTimer-"))
 				return -value;
@@ -327,6 +334,8 @@ public class AltosConfigData {
 
 		report_feet = AltosLib.MISSING;
 
+		gps_receiver = AltosLib.MISSING;
+
 		tracker_motion = AltosLib.MISSING;
 		tracker_interval = AltosLib.MISSING;
 
@@ -522,6 +531,8 @@ public class AltosConfigData {
 
 		try { report_feet = get_int(line, "Report in feet:"); } catch (Exception e) {}
 
+		try { gps_receiver = get_int(line, "GPS receiver:"); } catch (Exception e) {}
+
 		/* HAS_TRACKER */
 		try {
 			int[] values = get_values(line, "Tracker setting:");
@@ -773,6 +784,9 @@ public class AltosConfigData {
 		if (report_feet != AltosLib.MISSING)
 			report_feet = source.report_feet();
 
+		if (gps_receiver != AltosLib.MISSING)
+			gps_receiver = source.gps_receiver();
+
 		/* HAS_TRACKER */
 		if (tracker_motion != AltosLib.MISSING)
 			tracker_motion = source.tracker_motion();
@@ -830,6 +844,7 @@ public class AltosConfigData {
 		dest.set_beep(beep);
 		dest.set_radio_10mw(radio_10mw);
 		dest.set_report_feet(report_feet);
+		dest.set_gps_receiver(gps_receiver);
 		dest.set_tracker_motion(tracker_motion);
 		dest.set_tracker_interval(tracker_interval);
 	}
@@ -953,10 +968,13 @@ public class AltosConfigData {
 		if (radio_10mw != AltosLib.MISSING)
 			link.printf("c p %d\n", radio_10mw);
 
-		/* HAS_RADIO_10MW */
 		if (report_feet != AltosLib.MISSING)
 			link.printf("c u %d\n", report_feet);
 
+		/* HAS_GPS_MOSAIC */
+		if (gps_receiver != AltosLib.MISSING)
+			link.printf("c g %d\n", gps_receiver);
+
 		/* HAS_TRACKER */
 		if (tracker_motion != AltosLib.MISSING && tracker_interval != AltosLib.MISSING)
 			link.printf("c t %d %d\n", tracker_motion, tracker_interval);
